@@ -8,7 +8,7 @@ import time
 """
 DropBy
 Author: Jacob Vlijm
-Copyright © 2017-2020 Ubuntu Budgie Developers
+Copyright © 2017-2022 Ubuntu Budgie Developers
 Website=https://ubuntubudgie.org
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
@@ -47,7 +47,8 @@ def get_usb():
         except Exception:
             pass
         else:
-            if all(["usb" in v.get("DEVPATH"), uuid]):
+            devpath = v.get("DEVPATH")
+            if devpath and uuid and any(["usb" in devpath, "mmc" in devpath]):
                 relevant.append(uuid)
     return relevant
 
@@ -63,7 +64,7 @@ def get_mounted():
         usage = None
         try:
             usage = psutil.disk_usage(v.mountpoint)
-        except PermissionError:
+        except (PermissionError, OSError):
             continue
         dev = v.device
         # mountpoint is relevant for possible actions
@@ -79,8 +80,15 @@ def get_mounted():
 def uuid_todev(uuid):
     try:
         return subprocess.check_output(
-            ["findfs", "UUID=" + uuid]
+            ["/usr/sbin/findfs", "UUID=" + uuid]
         ).decode("utf-8").strip()
+    except FileNotFoundError:
+        try:
+            return subprocess.check_output(
+                ["/sbin/findfs", "UUID=" + uuid]
+            ).decode("utf-8").strip()
+        except (subprocess.CalledProcessError, TypeError):
+            return None
     except (subprocess.CalledProcessError, TypeError):
         return None
 
@@ -99,18 +107,18 @@ def get_volumes(allvols):
         # filter out usb devices
         uuid = v.get_uuid()
         if uuid in usb_devs:
+            path = uuid_todev(uuid)
             devdata = {
                 "volume": v,
                 "name": v.get_name(),
                 "uuid": uuid,
-                "device": uuid_todev(uuid),
+                "device": path,
                 "can_mount": v.can_mount(),
                 "icon": v.get_icon(),
                 "flashdrive": v.can_eject(),
                 "ismounted": v.get_mount(),
             }
             # try to determine usage
-            path = uuid_todev(uuid)
             try:
                 match = mounted_devspaths.index(path)
             except ValueError:
